from .concept_recognizer import ConceptRecognizer

class SDGIndicatorRecognizer(ConceptRecognizer):
	doc_list = [
		[
			('1.1.1', u"Proportion of population below the international poverty line, by sex, age, employment status and geographical location (urban/rural)"),
			('1.2.1', u"Proportion of population living below the national poverty line, by sex and age"),
			('1.2.2', u"Proportion of men, women and children of all ages living in poverty in all its dimensions according to national definitions"),
			('1.3.1', u"Proportion of population covered by social protection floors/systems, by sex, distinguishing children, unemployed persons, older persons, persons with disabilities, pregnant women, newborns, work-injury victims and the poor and the vulnerable"),
			('1.4.1', u"Proportion of population living in households with access to basic services"),
			('1.4.2', u"Proportion of total adult population with secure tenure rights to land, (a) with legally recognized documentation, and (b) who perceive their rights to land as secure, by sex and type of tenure"),
			('1.5.1', u"Number of deaths, missing persons and directly affected persons attributed to disasters per 100,000 population"),
			('1.5.2', u"Direct economic loss attributed to disasters in relation to global gross domestic product (GDP)"),
			('1.5.3', u"Number of countries that adopt and implement national disaster risk reduction strategies in line with the Sendai Framework for Disaster Risk Reduction 2015–2030"),
			('1.5.4', u"Proportion of local governments that adopt and implement local disaster risk reduction strategies in line with national disaster risk reduction strategies"),
			('1.a.1', u"Proportion of domestically generated resources allocated by the government directly to poverty reduction programmes"),
			('1.a.2', u"Proportion of total government spending on essential services (education, health and social protection)"),
			('1.a.3', u"Sum of total grants and non-debt-creating inflows directly allocated to poverty reduction programmes as a proportion of GDP"),
			('1.b.1', u"Proportion of government recurrent and capital spending to sectors that disproportionately benefit women, the poor and vulnerable groups"),
		],
		[
			('2.1.1', u"Prevalence of undernourishment"),
			('2.1.2', u"Prevalence of moderate or severe food insecurity in the population, based on the Food Insecurity Experience Scale (FIES)"),
			('2.2.1', u"Prevalence of stunting (height for age <-2 standard deviation from the median of the World Health Organization (WHO) Child Growth Standards) among children under 5 years of age"),
			('2.2.2', u"Prevalence of malnutrition (weight for height >+2 or <-2 standard deviation from the median of the WHO Child Growth Standards) among children under 5 years of age, by type (wasting and overweight)"),
			('2.3.1', u"Volume of production per labour unit by classes of farming/pastoral/forestry enterprise size"),
			('2.3.2', u"Average income of small-scale food producers, by sex and indigenous status"),
			('2.4.1', u"Proportion of agricultural area under productive and sustainable agriculture"),
			('2.5.1', u"Number of plant and animal genetic resources for food and agriculture secured in either medium- or long-term conservation facilities"),
			('2.5.2', u"Proportion of local breeds classified as being at risk, not at risk or at unknown level of risk of extinction"),
			('2.a.1', u"The agriculture orientation index for government expenditures"),
			('2.a.2', u"Total official flows (official development assistance plus other official flows) to the agriculture sector"),
			('2.b.1', u"Agricultural export subsidies"),
			('2.c.1', u"Indicator of food price anomalies"),
		],
		[
			('3.1.1', u"Maternal mortality ratio"),
			('3.1.2', u"Proportion of births attended by skilled health personnel"),
			('3.2.1', u"Under‑5 mortality rate"),
			('3.2.2', u"Neonatal mortality rate"),
			('3.3.1', u"Number of new HIV infections per 1,000 uninfected population, by sex, age and key populations"),
			('3.3.2', u"Tuberculosis incidence per 100,000 population"),
			('3.3.3', u"Malaria incidence per 1,000 population"),
			('3.3.4', u"Hepatitis B incidence per 100,000 population"),
			('3.3.5', u"Number of people requiring interventions against neglected tropical diseases"),
			('3.4.1', u"Mortality rate attributed to cardiovascular disease, cancer, diabetes or chronic respiratory disease"),
			('3.4.2', u"Suicide mortality rate"),
			('3.5.1', u"Coverage of treatment interventions (pharmacological, psychosocial and rehabilitation and aftercare services) for substance use disorders"),
			('3.5.2', u"Harmful use of alcohol, defined according to the national context as alcohol per capita consumption (aged 15 years and older) within a calendar year in litres of pure alcohol"),
			('3.6.1', u"Death rate due to road traffic injuries"),
			('3.7.1', u"Proportion of women of reproductive age (aged 15–49 years) who have their need for family planning satisfied with modern methods"),
			('3.7.2', u"Adolescent birth rate (aged 10–14 years; aged 15–19 years) per 1,000 women in that age group"),
			('3.8.1', u"Coverage of essential health services (defined as the average coverage of essential services based on tracer interventions that include reproductive, maternal, newborn and child health, infectious diseases, non-communicable diseases and service capacity and access, among the general and the most disadvantaged population)"),
			('3.8.2', u"Proportion of population with large household expenditures on health as a share of total household expenditure or income"),
			('3.9.1', u"Mortality rate attributed to household and ambient air pollution"),
			('3.9.2', u"Mortality rate attributed to unsafe water, unsafe sanitation and lack of hygiene (exposure to unsafe Water, Sanitation and Hygiene for All (WASH) services)"),
			('3.9.3', u"Mortality rate attributed to unintentional poisoning"),
			('3.a.1', u"Age-standardized prevalence of current tobacco use among persons aged 15 years and older"),
			('3.b.1', u"Proportion of the target population covered by all vaccines included in their national programme"),
			('3.b.2', u"Total net official development assistance to medical research and basic health sectors"),
			('3.b.3', u"Proportion of health facilities that have a core set of relevant essential medicines available and affordable on a sustainable basis"),
			('3.c.1', u"Health worker density and distribution"),
			('3.d.1', u"International Health Regulations (IHR) capacity and health emergency preparedness"),
		],
		[
			('4.1.1', u"Proportion of children and young people (a) in grades 2/3; (b) at the end of primary; and (c) at the end of lower secondary achieving at least a minimum proficiency level in (i) reading and (ii) mathematics, by sex"),
			('4.2.1', u"Proportion of children under 5 years of age who are developmentally on track in health, learning and psychosocial well-being, by sex"),
			('4.2.2', u"Participation rate in organized learning (one year before the official primary entry age), by sex"),
			('4.3.1', u"Participation rate of youth and adults in formal and non-formal education and training in the previous 12 months, by sex"),
			('4.4.1', u"Proportion of youth and adults with information and communications technology (ICT) skills, by type of skill"),
			('4.5.1', u"Parity indices (female/male, rural/urban, bottom/top wealth quintile and others such as disability status, indigenous peoples and conflict-affected, as data become available) for all education indicators on this list that can be disaggregated"),
			('4.6.1', u"Proportion of population in a given age group achieving at least a fixed level of proficiency in functional (a) literacy and (b) numeracy skills, by sex"),
			('4.7.1', u"Extent to which (i) global citizenship education and (ii) education for sustainable development, including gender equality and human rights, are mainstreamed at all levels in (a) national education policies; (b) curricula; (c) teacher education; and (d) student assessment"),
			('4.a.1', u"Proportion of schools with access to (a) electricity; (b) the Internet for pedagogical purposes; (c) computers for pedagogical purposes; (d) adapted infrastructure and materials for students with disabilities; (e) basic drinking water; (f) single-sex basic sanitation facilities; and (g) basic handwashing facilities (as per the WASH indicator definitions)"),
			('4.b.1', u"Volume of official development assistance flows for scholarships by sector and type of study"),
			('4.c.1', u"Proportion of teachers in: (a) pre-primary; (b) primary; (c) lower secondary; and (d) upper secondary education who have received at least the minimum organized teacher training (e.g. pedagogical training) pre-service or in-service required for teaching at the relevant level in a given country"),
		],
		[
			('5.1.1', u"Whether or not legal frameworks are in place to promote, enforce and monitor equality and non‑discrimination on the basis of sex"),
			('5.2.1', u"Proportion of ever-partnered women and girls aged 15 years and older subjected to physical, sexual or psychological violence by a current or former intimate partner in the previous 12 months, by form of violence and by age"),
			('5.2.2', u"Proportion of women and girls aged 15 years and older subjected to sexual violence by persons other than an intimate partner in the previous 12 months, by age and place of occurrence"),
			('5.3.1', u"Proportion of women aged 20–24 years who were married or in a union before age 15 and before age 18"),
			('5.3.2', u"Proportion of girls and women aged 15–49 years who have undergone female genital mutilation/cutting, by age"),
			('5.4.1', u"Proportion of time spent on unpaid domestic and care work, by sex, age and location"),
			('5.5.1', u"Proportion of seats held by women in (a) national parliaments and (b) local governments"),
			('5.5.2', u"Proportion of women in managerial positions"),
			('5.6.1', u"Proportion of women aged 15–49 years who make their own informed decisions regarding sexual relations, contraceptive use and reproductive health care"),
			('5.6.2', u"Number of countries with laws and regulations that guarantee full and equal access to women and men aged 15 years and older to sexual and reproductive health care, information and education"),
			('5.a.1', u"(a) Proportion of total agricultural population with ownership or secure rights over agricultural land, by sex; and (b) share of women among owners or rights-bearers of agricultural land, by type of tenure"),
			('5.a.2', u"Proportion of countries where the legal framework (including customary law) guarantees women’s equal rights to land ownership and/or control"),
			('5.b.1', u"Proportion of individuals who own a mobile telephone, by sex"),
			('5.c.1', u"Proportion of countries with systems to track and make public allocations for gender equality and women’s empowerment"),
		],
		[
			('6.1.1', u"Proportion of population using safely managed drinking water services"),
			('6.2.1', u"Proportion of population using (a) safely managed sanitation services and (b) a hand-washing facility with soap and water"),
			('6.3.1', u"Proportion of wastewater safely treated"),
			('6.3.2', u"Proportion of bodies of water with good ambient water quality"),
			('6.4.1', u"Change in water-use efficiency over time"),
			('6.4.2', u"Level of water stress: freshwater withdrawal as a proportion of available freshwater resources"),
			('6.5.1', u"Degree of integrated water resources management implementation (0–100)"),
			('6.5.2', u"Proportion of transboundary basin area with an operational arrangement for water cooperation"),
			('6.6.1', u"Change in the extent of water-related ecosystems over time"),
			('6.a.1', u"Amount of water- and sanitation-related official development assistance that is part of a government-coordinated spending plan"),
			('6.b.1', u"Proportion of local administrative units with established and operational policies and procedures for participation of local communities in water and sanitation management"),
		],
		[
			('7.1.1', u"Proportion of population with access to electricity"),
			('7.1.2', u"Proportion of population with primary reliance on clean fuels and technology"),
			('7.2.1', u"Renewable energy share in the total final energy consumption"),
			('7.3.1', u"Energy intensity measured in terms of primary energy and GDP"),
			('7.a.1', u"International financial flows to developing countries in support of clean energy research and development and renewable energy production, including in hybrid systems"),
			('7.b.1', u"Investments in energy efficiency as a proportion of GDP and the amount of foreign direct investment in financial transfer for infrastructure and technology to sustainable development services"),
		],
		[
			('8.1.1', u"Annual growth rate of real GDP per capita"),
			('8.2.1', u"Annual growth rate of real GDP per employed person"),
			('8.3.1', u"Proportion of informal employment in non‑agriculture employment, by sex"),
			('8.4.1', u"Material footprint, material footprint per capita, and material footprint per GDP"),
			('8.4.2', u"Domestic material consumption, domestic material consumption per capita, and domestic material consumption per GDP"),
			('8.5.1', u"Average hourly earnings of female and male employees, by occupation, age and persons with disabilities"),
			('8.5.2', u"Unemployment rate, by sex, age and persons with disabilities"),
			('8.6.1', u"Proportion of youth (aged 15–24 years) not in education, employment or training"),
			('8.7.1', u"Proportion and number of children aged 5–17 years engaged in child labour, by sex and age"),
			('8.8.1', u"Frequency rates of fatal and non-fatal occupational injuries, by sex and migrant status"),
			('8.8.2', u"Level of national compliance with labour rights (freedom of association and collective bargaining) based on International Labour Organization (ILO) textual sources and national legislation, by sex and migrant status"),
			('8.9.1', u"Tourism direct GDP as a proportion of total GDP and in growth rate"),
			('8.9.2', u"Proportion of jobs in sustainable tourism industries out of total tourism jobs"),
			('8.10.1', u"(a) Number of commercial bank branches per 100,000 adults and (b) number of automated teller machines (ATMs) per 100,000 adults"),
			('8.10.2', u"Proportion of adults (15 years and older) with an account at a bank or other financial institution or with a mobile-money-service provider"),
			('8.a.1', u"Aid for Trade commitments and disbursements"),
			('8.b.1', u"Existence of a developed and operationalized national strategy for youth employment, as a distinct strategy or as part of a national employment strategy"),
		],
		[
			('9.1.1', u"Proportion of the rural population who live within 2 km of an all-season road"),
			('9.1.2', u"Passenger and freight volumes, by mode of transport"),
			('9.2.1', u"Manufacturing value added as a proportion of GDP and per capita"),
			('9.2.2', u"Manufacturing employment as a proportion of total employment"),
			('9.3.1', u"Proportion of small-scale industries in total industry value added"),
			('9.3.2', u"Proportion of small-scale industries with a loan or line of credit"),
			('9.4.1', u"CO2 emission per unit of value added"),
			('9.5.1', u"Research and development expenditure as a proportion of GDP"),
			('9.5.2', u"Researchers (in full-time equivalent) per million inhabitants"),
			('9.a.1', u"Total official international support (official development assistance plus other official flows) to infrastructure"),
			('9.b.1', u"Proportion of medium and high-tech industry value added in total value added"),
			('9.c.1', u"Proportion of population covered by a mobile network, by technology"),
		],
		[
			('10.1.1', u"Growth rates of household expenditure or income per capita among the bottom 40 per cent of the population and the total population"),
			('10.2.1', u"Proportion of people living below 50 per cent of median income, by sex, age and persons with disabilities"),
			('10.3.1', u"Proportion of population reporting having personally felt discriminated against or harassed in the previous 12 months on the basis of a ground of discrimination prohibited under international human rights law"),
			('10.4.1', u"Labour share of GDP, comprising wages and social protection transfers"),
			('10.5.1', u"Financial Soundness Indicators"),
			('10.6.1', u"Proportion of members and voting rights of developing countries in international organizations"),
			('10.7.1', u"Recruitment cost borne by employee as a proportion of yearly income earned in country of destination"),
			('10.7.2', u"Number of countries that have implemented well-managed migration policies"),
			('10.a.1', u"Proportion of tariff lines applied to imports from least developed countries and developing countries with zero-tariff"),
			('10.b.1', u"Total resource flows for development, by recipient and donor countries and type of flow (e.g. official development assistance, foreign direct investment and other flows)"),
			('10.c.1', u"Remittance costs as a proportion of the amount remitted"),
		],
		[
			('11.1.1', u"Proportion of urban population living in slums, informal settlements or inadequate housing"),
			('11.2.1', u"Proportion of population that has convenient access to public transport, by sex, age and persons with disabilities"),
			('11.3.1', u"Ratio of land consumption rate to population growth rate"),
			('11.3.2', u"Proportion of cities with a direct participation structure of civil society in urban planning and management that operate regularly and democratically"),
			('11.4.1', u"Total expenditure (public and private) per capita spent on the preservation, protection and conservation of all cultural and natural heritage, by type of heritage (cultural, natural, mixed and World Heritage Centre designation), level of government (national, regional and local/municipal), type of expenditure (operating expenditure/investment) and type of private funding (donations in kind, private non-profit sector and sponsorship)"),
			('11.5.1', u"Number of deaths, missing persons and directly affected persons attributed to disasters per 100,000 population"),
			('11.5.2', u"Direct economic loss in relation to global GDP, damage to critical infrastructure and number of disruptions to basic services, attributed to disasters"),
			('11.6.1', u"Proportion of urban solid waste regularly collected and with adequate final discharge out of total urban solid waste generated, by cities"),
			('11.6.2', u"Annual mean levels of fine particulate matter (e.g. PM2.5 and PM10) in cities (population weighted)"),
			('11.7.1', u"Average share of the built-up area of cities that is open space for public use for all, by sex, age and persons with disabilities"),
			('11.7.2', u"Proportion of persons victim of physical or sexual harassment, by sex, age, disability status and place of occurrence, in the previous 12 months"),
			('11.a.1', u"Proportion of population living in cities that implement urban and regional development plans integrating population projections and resource needs, by size of city"),
			('11.b.1', u"Number of countries that adopt and implement national disaster risk reduction strategies in line with the Sendai Framework for Disaster Risk Reduction 2015–2030"),
			('11.b.2', u"Proportion of local governments that adopt and implement local disaster risk reduction strategies in line with national disaster risk reduction strategies"),
			('11.c.1', u"Proportion of financial support to the least developed countries that is allocated to the construction and retrofitting of sustainable, resilient and resource-efficient buildings utilizing local materials"),
		],
		[
			('12.1.1', u"Number of countries with sustainable consumption and production (SCP) national action plans or SCP mainstreamed as a priority or a target into national policies"),
			('12.2.1', u"Material footprint, material footprint per capita, and material footprint per GDP"),
			('12.2.2', u"Domestic material consumption, domestic material consumption per capita, and domestic material consumption per GDP"),
			('12.3.1', u"Global food loss index"),
			('12.4.1', u"Number of parties to international multilateral environmental agreements on hazardous waste, and other chemicals that meet their commitments and obligations in transmitting information as required by each relevant agreement"),
			('12.4.2', u"Hazardous waste generated per capita and proportion of hazardous waste treated, by type of treatment"),
			('12.5.1', u"National recycling rate, tons of material recycled"),
			('12.6.1', u"Number of companies publishing sustainability reports"),
			('12.7.1', u"Number of countries implementing sustainable public procurement policies and action plans"),
			('12.8.1', u"Extent to which (i) global citizenship education and (ii) education for sustainable development (including climate change education) are mainstreamed in (a) national education policies; (b) curricula; (c) teacher education; and (d) student assessment"),
			('12.a.1', u"Amount of support to developing countries on research and development for sustainable consumption and production and environmentally sound technologies"),
			('12.b.1', u"Number of sustainable tourism strategies or policies and implemented action plans with agreed monitoring and evaluation tools"),
			('12.c.1', u"Amount of fossil-fuel subsidies per unit of GDP (production and consumption) and as a proportion of total national expenditure on fossil fuels"),
		],
		[
			('13.1.1', u"Number of deaths, missing persons and directly affected persons attributed to disasters per 100,000 population"),
			('13.1.2', u"Number of countries that adopt and implement national disaster risk reduction strategies in line with the Sendai Framework for Disaster Risk Reduction 2015–2030"),
			('13.1.3', u"Proportion of local governments that adopt and implement local disaster risk reduction strategies in line with national disaster risk reduction strategies"),
			('13.2.1', u"Number of countries that have communicated the establishment or operationalization of an integrated policy/strategy/plan which increases their ability to adapt to the adverse impacts of climate change, and foster climate resilience and low greenhouse gas emissions development in a manner that does not threaten food production (including a national adaptation plan, nationally determined contribution, national communication, biennial update report or other)"),
			('13.3.1', u"Number of countries that have integrated mitigation, adaptation, impact reduction and early warning into primary, secondary and tertiary curricula"),
			('13.3.2', u"Number of countries that have communicated the strengthening of institutional, systemic and individual capacity-building to implement adaptation, mitigation and technology transfer, and development actions"),
			('13.a.1', u"Mobilized amount of United States dollars per year between 2020 and 2025 accountable towards the $100 billion commitment"),
			('13.b.1', u"Number of least developed countries and small island developing States that are receiving specialized support, and amount of support, including finance, technology and capacity-building, for mechanisms for raising capacities for effective climate change-related planning and management, including focusing on women, youth and local and marginalized communities"),
		],
		[
			('14.1.1', u"Index of coastal eutrophication and floating plastic debris density"),
			('14.2.1', u"Proportion of national exclusive economic zones managed using ecosystem-based approaches"),
			('14.3.1', u"Average marine acidity (pH) measured at agreed suite of representative sampling stations"),
			('14.4.1', u"Proportion of fish stocks within biologically sustainable levels"),
			('14.5.1', u"Coverage of protected areas in relation to marine areas"),
			('14.6.1', u"Progress by countries in the degree of implementation of international instruments aiming to combat illegal, unreported and unregulated fishing"),
			('14.7.1', u"Sustainable fisheries as a proportion of GDP in small island developing States, least developed countries and all countries"),
			('14.a.1', u"Proportion of total research budget allocated to research in the field of marine technology"),
			('14.b.1', u"Progress by countries in the degree of application of a legal/regulatory/policy/institutional framework which recognizes and protects access rights for small-scale fisheries"),
			('14.c.1', u"Number of countries making progress in ratifying, accepting and implementing through legal, policy and institutional frameworks, ocean-related instruments that implement international law, as reflected in the United Nations Convention on the Law of the Sea, for the conservation and sustainable use of the oceans and their resources"),
		],
		[
			('15.1.1', u"Forest area as a proportion of total land area"),
			('15.1.2', u"Proportion of important sites for terrestrial and freshwater biodiversity that are covered by protected areas, by ecosystem type"),
			('15.2.1', u"Progress towards sustainable forest management"),
			('15.3.1', u"Proportion of land that is degraded over total land area"),
			('15.4.1', u"Coverage by protected areas of important sites for mountain biodiversity"),
			('15.4.2', u"Mountain Green Cover Index"),
			('15.5.1', u"Red List Index"),
			('15.6.1', u"Number of countries that have adopted legislative, administrative and policy frameworks to ensure fair and equitable sharing of benefits"),
			('15.7.1', u"Proportion of traded wildlife that was poached or illicitly trafficked"),
			('15.8.1', u"Proportion of countries adopting relevant national legislation and adequately resourcing the prevention or control of invasive alien species"),
			('15.9.1', u"Progress towards national targets established in accordance with Aichi Biodiversity Target 2 of the Strategic Plan for Biodiversity 2011–2020"),
			('15.a.1', u"Official development assistance and public expenditure on conservation and sustainable use of biodiversity and ecosystems"),
			('15.b.1', u"Official development assistance and public expenditure on conservation and sustainable use of biodiversity and ecosystems"),
			('15.c.1', u"Proportion of traded wildlife that was poached or illicitly trafficked"),
		],
		[
			('16.1.1', u"Number of victims of intentional homicide per 100,000 population, by sex and age"),
			('16.1.2', u"Conflict-related deaths per 100,000 population, by sex, age and cause"),
			('16.1.3', u"Proportion of population subjected to (a) physical violence, (b) psychological violence and (c) sexual violence in the previous 12 months"),
			('16.1.4', u"Proportion of population that feel safe walking alone around the area they live"),
			('16.2.1', u"Proportion of children aged 1–17 years who experienced any physical punishment and/or psychological aggression by caregivers in the past month"),
			('16.2.2', u"Number of victims of human trafficking per 100,000 population, by sex, age and form of exploitation"),
			('16.2.3', u"Proportion of young women and men aged 18–29 years who experienced sexual violence by age 18"),
			('16.3.1', u"Proportion of victims of violence in the previous 12 months who reported their victimization to competent authorities or other officially recognized conflict resolution mechanisms"),
			('16.3.2', u"Unsentenced detainees as a proportion of overall prison population"),
			('16.4.1', u"Total value of inward and outward illicit financial flows (in current United States dollars)"),
			('16.4.2', u"Proportion of seized, found or surrendered arms whose illicit origin or context has been traced or established by a competent authority in line with international instruments"),
			('16.5.1', u"Proportion of persons who had at least one contact with a public official and who paid a bribe to a public official, or were asked for a bribe by those public officials, during the previous 12 months"),
			('16.5.2', u"Proportion of businesses that had at least one contact with a public official and that paid a bribe to a public official, or were asked for a bribe by those public officials during the previous 12 months"),
			('16.6.1', u"Primary government expenditures as a proportion of original approved budget, by sector (or by budget codes or similar)"),
			('16.6.2', u"Proportion of population satisfied with their last experience of public services"),
			('16.7.1', u"Proportions of positions (by sex, age, persons with disabilities and population groups) in public institutions (national and local legislatures, public service, and judiciary) compared to national distributions"),
			('16.7.2', u"Proportion of population who believe decision-making is inclusive and responsive, by sex, age, disability and population group"),
			('16.8.1', u"Proportion of members and voting rights of developing countries in international organizations"),
			('16.9.1', u"Proportion of children under 5 years of age whose births have been registered with a civil authority, by age"),
			('16.10.1', u"Number of verified cases of killing, kidnapping, enforced disappearance, arbitrary detention and torture of journalists, associated media personnel, trade unionists and human rights advocates in the previous 12 months"),
			('16.10.2', u"Number of countries that adopt and implement constitutional, statutory and/or policy guarantees for public access to information"),
			('16.a.1', u"Existence of independent national human rights institutions in compliance with the Paris Principles"),
			('16.b.1', u"Proportion of population reporting having personally felt discriminated against or harassed in the previous 12 months on the basis of a ground of discrimination prohibited under international human rights law"),
		],
		[
			('17.1.1', u"Total government revenue as a proportion of GDP, by source"),
			('17.1.2', u"Proportion of domestic budget funded by domestic taxes"),
			('17.2.1', u"Net official development assistance, total and to least developed countries, as a proportion of the Organization for Economic Cooperation and Development (OECD) Development Assistance Committee donors’ gross national income (GNI)"),
			('17.3.1', u"Foreign direct investment (FDI), official development assistance and South-South cooperation as a proportion of total domestic budget"),
			('17.3.2', u"Volume of remittances (in United States dollars) as a proportion of total GDP"),
			('17.4.1', u"Debt service as a proportion of exports of goods and services"),
			('17.5.1', u"Number of countries that adopt and implement investment promotion regimes for least developed countries"),
			('17.6.1', u"Number of science and/or technology cooperation agreements and programmes between countries, by type of cooperation"),
			('17.6.2', u"Fixed Internet broadband subscriptions per 100 inhabitants, by speed"),
			('17.7.1', u"Total amount of approved funding for developing countries to promote the development, transfer, dissemination and diffusion of environmentally sound technologies"),
			('17.8.1', u"Proportion of individuals using the Internet"),
			('17.9.1', u"Dollar value of financial and technical assistance (including through North-South, South‑South and triangular cooperation) committed to developing countries"),
			('17.10.1', u"Worldwide weighted tariff-average"),
			('17.11.1', u"Developing countries’ and least developed countries’ share of global exports"),
			('17.12.1', u"Average tariffs faced by developing countries, least developed countries and small island developing States"),
			('17.13.1', u"Macroeconomic Dashboard"),
			('17.14.1', u"Number of countries with mechanisms in place to enhance policy coherence of sustainable development"),
			('17.15.1', u"Extent of use of country-owned results frameworks and planning tools by providers of development cooperation"),
			('17.16.1', u"Number of countries reporting progress in multi-stakeholder development effectiveness monitoring frameworks that support the achievement of the sustainable development goals"),
			('17.17.1', u"Amount of United States dollars committed to (a) public-private partnerships and (b) civil society partnerships"),
			('17.18.1', u"Proportion of sustainable development indicators produced at the national level with full disaggregation when relevant to the target, in accordance with the Fundamental Principles of Official Statistics"),
			('17.18.2', u"Number of countries that have national statistical legislation that complies with the Fundamental Principles of Official Statistics"),
			('17.18.3', u"Number of countries with a national statistical plan that is fully funded and under implementation, by source of funding"),
			('17.19.1', u"Dollar value of all resources made available to strengthen statistical capacity in developing countries"),
			('17.19.2', u"Proportion of countries that (a) have conducted at least one population and housing census in the last 10 years; and (b) have achieved 100 per cent birth registration and 80 per cent death registration"),
		]
	]
